:py:mod:`byma.iteral.stationary`
================================

.. py:module:: byma.iteral.stationary


Submodules
----------
.. toctree::
   :titlesonly:
   :maxdepth: 1

   OrthogonalSubspace/index.rst
   Stationary/index.rst


Package Contents
----------------

Classes
~~~~~~~

.. autoapisummary::

   byma.iteral.stationary.Stationary




.. py:class:: Stationary


   Defines default options for the Stationary method


